@@ -214,7 +214,7 @@ class tPandora(QtCore.QThread):
 							self.crash = 0
 
 						if re.match("^[Q|q]\s+(.+)",stations.group(2).lstrip()):
-							station = re.match("^[Q|q]\s+(.+)",stations.group(2).lstrip()).group(1)
+							station = re.match("^[Q|q]\s+(.+)",stations.group(2).lstrip()).group(1) + " *"
 						else:
 							station = stations.group(2).lstrip()
 
@@ -296,7 +296,7 @@ class MyForm(QtGui.QMainWindow):
 		self.station = i
 		for station in self.p.stations:
 			i = i + 1
-			if self.c.lastplayed == station:
+			if self.c.lastplayed == station.rstrip(" *"):
 				self.station = i
 		if not self.station == -1:
 			self.p.pandora.stdin.write(str(self.station)+"\n")
@@ -352,7 +352,7 @@ class MyForm(QtGui.QMainWindow):
 			QtGui.QMessageBox.warning(self, 'Station Created', 'Your station has been created.')
 			self.c.lastplayed = self.ui.listStations.currentText()+" Radio"
 			f = open(os.path.expanduser("~")+'/.config/pianobar/lastplayed', 'w')
-			f.write(self.ui.listStations.currentText())
+			f.write(self.ui.listStations.currentText().replace(" *", ""))
 			f.close()
 			self.p.pandora.stdin.write(self.c.act_stationchange)
 		else:
@@ -364,7 +364,8 @@ class MyForm(QtGui.QMainWindow):
 			self.p.pandora.stdin.write(str(self.station)+"\n")
 			self.ui.btnPlay.setStyleSheet("background-color: "+ self.c.color + ";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/playing-trans.png);")
 			f = open(os.path.expanduser("~")+'/.config/pianobar/lastplayed', 'w')
-			f.write(self.ui.listStations.currentText())
+			self.ui.listStations.currentText()
+			f.write(self.ui.listStations.currentText().replace(" *", ""))
 			f.close()
 
 	def tiredSong(self):
@@ -400,10 +401,11 @@ class MyForm(QtGui.QMainWindow):
 
 	def uAlbum(self):
 		if not self.a.iUrl == "None":
-			myUrl = QtCore.QUrl.fromEncoded(self.a.iUrl)
-			self.ui.albumArt.load(myUrl)
+			#myUrl = QtCore.QUrl.fromEncoded(self.a.iUrl)
+			#self.ui.albumArt.load(myUrl)
+			self.ui.albumArt.setHtml("<img style='width: 100%; height: 95%' src='"+self.a.iUrl+"'>")
 		else:
-			self.ui.albumArt.setHtml("<img src='qrc:///img/img/no-image-trans.png'>")
+			self.ui.albumArt.setHtml("<img style='widt: 100%; height: 95%' src='qrc:///img/img/no-image-trans.png'>")
 		
 	def doLove(self):
 		if self.p.last == "song":
@@ -442,7 +444,7 @@ class MyForm(QtGui.QMainWindow):
 		if self.p.last == "stations":
 			self.p.pandora.stdin.write(str(self.ui.listStations.currentIndex())+"\n")
 			f = open(os.path.expanduser("~")+'/.config/pianobar/lastplayed', 'w')
-			f.write(self.ui.listStations.currentText())
+			f.write(self.ui.listStations.currentText().replace(" *", ""))
 			f.close()
 		else:
 			self.p.pandora.stdin.write(self.c.act_songpause)
@@ -478,6 +480,10 @@ class MyForm(QtGui.QMainWindow):
 				self.showUsername()
 				self.showPassword()
 			self.p.crash += 1
+			self.p.drun = 0
+			if not self.p.pandora.stdin.closed:
+				self.p.pandora.stdin.write('\n'+self.c.act_quit)
+			self.p.pandora.wait()
 			self.p.drun = 1
 			self.p.start()
 		else:
